//@line 36 "/builds/slave/rel-m-rel-lnx-mb-rpk-2/mozilla-release/mobile/locales/en-US/mobile-l10n.js"

//@line 38 "/builds/slave/rel-m-rel-lnx-mb-rpk-2/mozilla-release/mobile/locales/en-US/mobile-l10n.js"

pref("general.useragent.locale", "et");
